.. _changelog_toplevel:

Changes and Migration
=====================

Migration Guides
----------------

SQLAlchemy migration guides are now available within the main documentation.

.. toctree::
	:maxdepth: 1

	migration_07
	migration_06
	migration_05
	migration_04

Change logs
-----------

SQLAlchemy changelogs are now available within the main documentation.

.. toctree::
   :maxdepth: 2

   changelog_07
   changelog_06
   changelog_05
   changelog_04
   changelog_03
   changelog_02
   changelog_01

